<template>
  <div class="workstation viewWrap">
    <a ref="download" style="display: none" />
    <h2>工站管理</h2>
    <!-- 数据功能按钮区 -->
    <div>
      <el-button
        type="primary"
        icon="el-icon-plus"
        style="width: 100px;"
        @click="handleFormDataAdd"
        >添加</el-button
      >
      <el-button
        type="primary"
        icon="el-icon-download"
        style="width: 100px;"
        @click="handleExport"
        >导出</el-button
      >
    </div>

    <!-- 数据表格区 -->
    <el-table
      stripe
      :data="tableData"
      height="0"
      style="margin-top: 20px;"
    >
      <el-table-column type="index" label="序号"> </el-table-column>
      <el-table-column prop="name" label="名称"> </el-table-column>
      <el-table-column prop="lineName" label="生产线"> </el-table-column>
      <el-table-column label="二维码">
        <template slot-scope="scope">
          <el-button
            @click.native.prevent="handleShowCode(scope.row)"
            type="text"
            size="small"
          >
            <i class="iconfont icon-erweima" style="font-size: 12px;"></i>
            查看二维码
          </el-button>
        </template>
      </el-table-column>
      <el-table-column prop="remark" label="备注" show-overflow-tooltip>
      </el-table-column>
      <el-table-column prop="disabled" label="状态" width="180">
        <template slot-scope="scope">
          <el-switch
            v-model="scope.row.disabled"
            active-color="#ff0000"
            active-text="禁用"
            inactive-color="#409EFF"
            inactive-text="启用"
            @change="handleDisabled(scope.row)"
          >
          </el-switch>
        </template>
      </el-table-column>
      <el-table-column label="操作" width="100">
        <template slot-scope="scope">
          <el-button
            icon="el-icon-edit"
            @click.native.prevent="handleFormDataEdit(scope.row)"
            type="text"
            size="small"
          >
            编辑
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <!-- 分页组件 -->
    <el-pagination
      style="margin-top: 20px;"
      @size-change="onGetTableData"
      @current-change="onGetTableData"
      :current-page.sync="pageCurr"
      :page-size.sync="pageSize"
      :page-sizes="[10, 20, 50, 100]"
      layout="total, sizes, prev, pager, next, jumper"
      :total="total"
    >
    </el-pagination>

    <!-- 表单 -->
    <el-dialog
      title="工站信息"
      :visible.sync="showFromData"
      width="600px"
      :before-close="handleFormDataClose"
    >
      <el-form
        :model="formData"
        :rules="formRules"
        ref="formData"
        label-width="140px"
      >
        <el-form-item label="用户ID" prop="id" style="display: none;">
          <el-input
            style="width:220px"
            v-model="formData.id"
            disabled
          ></el-input>
        </el-form-item>
        <el-form-item label="生产线" prop="lineId">
          <el-select
            v-model="formData.lineId"
            placeholder="请选择"
            style="width:220px;"
            clearable
          >
            <el-option v-for="(item, index) in selectData" :key="index" :label="item.name" :value="item.id"> </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="名称" prop="name">
          <el-input
            style="width:220px"
            v-model="formData.name"
            clearable
          ></el-input>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input
            style="width:220px"
            v-model="formData.remark"
            clearable
          ></el-input>
        </el-form-item>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button @click="handleFormDataClose">取 消</el-button>
        <el-button type="primary" @click="handleFormDataSubmit"
          >确 定</el-button
        >
      </span>
    </el-dialog>

    <!-- 二维码 -->
    <div class="codeWrap" v-show="showCode" @click="handleCloseCode">
      <transition name="el-zoom-in-center">
        <img v-show="showCode" :src="imgBase64">
      </transition>
      <div class="codeMessage">点击屏幕关闭二维码</div>
    </div>
  </div>
</template>

<style lang="less" scoped></style>

<script>

export default {
  name: "workstation",
  components: {},
  data() {
    return {
      pageSize: 10,
      pageCurr: 1,
      total: 0,
      tableData: [],
      showFromData: false,
      formData: {
        id: null,
        lineId: null,
        name: null,
        remark: null,
      },
      formRules: {
        lineId: [{ required: true, message: "必填项", trigger: "blur" }],
        name: [{ required: true, message: "必填项", trigger: "blur" }],
      },
      showCode: false,
      codeObj: null,
      selectData: [],
      imgBase64: null,
    };
  },
  computed: {},
  mounted() {
    this.onGetTableData();
  },
  methods: {
    // 获取表格数据
    onGetTableData: function() {
      var that = this;
      var data = {
        pageSize: this.pageSize,
        pageCurr: this.pageCurr
      }
      that
        .$axiosAdmin({
          method: "post",
          url: "platform/station/some",
          data
        })
        .then((res) => {
          if (res.success == true) {
            that.tableData = res.content.obj;
            that.total = res.content.itemTotal;
          } else {
            that.$alert(res.content, "提示", {
              confirmButtonText: "确定",
            });
          }
        })
        .catch((err) => {
          console.log(err);
        });
    },
    // 获取生产线数据
    onGetSelectData: function () {
      var that = this;
      that
        .$axiosAdmin({
          method: "get",
          url: "platform/proLine/all",
        })
        .then((res) => {
          if (res.success == true) {
            console.log('onGetSelectData =>', res);
            this.selectData = res.content
          } else {
            that.$alert(res.content, "提示", {
              confirmButtonText: "确定",
            });
          }
        })
        .catch((err) => {
          console.log(err);
        });
    },
    // 删除确认
    handleDelete(row) {
      this.$confirm(`此操作将删除 ${row.name} , 是否继续?`, "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          this.onDelete(row);
        })
        .catch(() => {
          this.$message({
            type: "info",
            message: "已取消",
          });
        });
    },
    // 执行删除
    onDelete: function(row) {
      var that = this;
      var params = {
        id: row.id,
      };
      that
        .$axiosAdmin({
          method: "get",
          url: "platform/station/delete",
          params: params,
        })
        .then((res) => {
          if (res.success == true) {
            that.$message({
              type: "success",
              message: "已成功",
            });
          } else {
            that.$alert(res.content, "提示", {
              confirmButtonText: "确定",
            });
          }
          that.onGetTableData();
        })
        .catch((err) => {
          console.log(err);
        });
    },
    // 添加
    handleFormDataAdd: function() {
      this.onGetSelectData()
      this.formData.id = null;
      this.formData.name = null;
      this.formData.lineId = null;
      this.formData.remark = null;
      this.showFromData = true;
    },
    // 关闭
    handleFormDataClose: function() {
      this.formData.id = null;
      this.formData.name = null;
      this.formData.lineId = null;
      this.formData.remark = null;
      this.showFromData = false;
      this.$refs["formData"].resetFields();
    },
    // 编辑
    handleFormDataEdit: function(row) {
      this.onGetSelectData()
      this.formData.id = row.id;
      this.formData.name = row.name;
      this.formData.lineId = row.lineId;
      this.formData.remark = row.remark;
      this.showFromData = true;
    },
    // 提交数据确认
    handleFormDataSubmit: function() {
      this.$confirm(`此操作将保存并更新数据, 是否继续?`, "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          this.onFormDataSubmit();
        })
        .catch(() => {
          this.$message({
            type: "info",
            message: "已取消",
          });
        });
    },
    // 提交数据
    onFormDataSubmit: function() {
      var that = this;
      var url, data;
      if (this.formData.id) {
        url = "platform/station/update";
        data = {
          id: this.formData.id,
          name: this.formData.name,
          lineId: this.formData.lineId,
          remark: this.formData.remark,
        };
      } else {
        url = "platform/station/save";
        data = {
          name: this.formData.name,
          lineId: this.formData.lineId,
          remark: this.formData.remark,
        };
      }
      that
        .$axiosAdmin({
          method: "post",
          url: url,
          data: JSON.stringify(data),
        })
        .then((res) => {
          if (res.success == true) {
            that.$message({
              type: "success",
              message: "已成功",
            });
            that.handleFormDataClose();
            that.onGetTableData();
          } else {
            that.$alert(res.content, "提示", {
              confirmButtonText: "确定",
            });
          }
        })
        .catch((err) => {
          console.log(err);
        });
    },
    // 生成二维码
    // 系统中工站,103后加数据库工站记录ID,共22位数字
    handleShowCode: function(row) {
      this.imgBase64 = row.qrCode
      this.showCode = true;
    },
    // 关闭二维码
    handleCloseCode: function() {
      this.imgBase64 = null
      this.showCode = false;
    },
    // 状态变更确认
    handleDisabled(row) {
      this.$confirm(`此操作将变更 ${row.name} 的状态, 是否继续?`, "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          this.onDisabled(row);
        })
        .catch(() => {
          this.onGetTableData();
          this.$message({
            type: "info",
            message: "已取消",
          });
        });
    },
    // 执行状态变更
    onDisabled: function(row) {
      var that = this;
      var data = {
        id: row.id,
        disabled: row.disabled,
      };
      that
        .$axiosAdmin({
          method: "post",
          url: "platform/station/disabled",
          data: JSON.stringify(data),
        })
        .then((res) => {
          if (res.success == true) {
            that.$message({
              type: "success",
              message: "已成功",
            });
          } else {
            that.$alert(res.content, "提示", {
              confirmButtonText: "确定",
            });
          }
          that.onGetTableData();
        })
        .catch((err) => {
          console.log(err);
          that.onGetTableData();
        });
    },
    // 导出
    handleExport: function () {
      var that = this;
      that
        .$axiosAdmin({
          method: "post",
          responseType: "blob",
          url: "platform/station/export",
          data: JSON.stringify({
            "type":""
          })
        })
        .then((res) => {
          const blob = res;
          that.$refs.download.href = window.URL.createObjectURL(new Blob([blob], {type:'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'}));
          that.$refs.download.download = `工站信息.xlsx`;
          that.$refs.download.click();
        })
        .catch((err) => {
          console.log(err);
        });
    },
  },
};
</script>
